@@ -12,7 +12,8 @@ from typing import TypeVar
 T = TypeVar("T")
 
 
-class IWorkerJoin(object):
+class IJoin(object):
+    __slots__ = "_recorder", "_gather"
 
     async def join(self, *args, **kwargs) -> T:
         raise NotImplementedError("NotImplemented .join() -> ")
